@@ -65,7 +65,9 @@ def filed(key,inquire=[]):
         'AlertRuleNamesID': ParaDateAnyRobotServer(key).getAlertRuleNamesId,
         'AlertScenarioID': ParaDateAnyRobotServer(key).getAlertScenarioId,
         'DeleteAlertRuleNamesID': ParaDateAnyRobotServer(key).getDeleteAlertRuleNamesId,
-        'UpdateTimeID': ParaDateFiledServer().getUpdateTime
+        'UpdateTimeID': ParaDateFiledServer().getUpdateTime,
+        'UtcStartID': ParaDateFiledServer().getUtcStartTime,
+        'UtcEndID': ParaDateFiledServer().getUtcEndTime
     }
 
     switcher = SERVICE_KPI_
